==> v8.3.zip: ru_twords_ru_tw/bible/other/assembly.md <==
# собрание, собор

## Определение:

Собрание — это группа людей, собранных с целью обсуждения какой-либо проблемы или для принятия решения.

* Собранием может быть группа, организованная официально и на постоянной основе, или же это может быть группа, собирающаяся время от времени по особому случаю или для определённой цели.
* В Ветхом Завете существовало специальное собрание, называемое “торжественным собранием”, когда израильский народ собирался для того, чтобы прославить Божье имя.
* Иногда это слово указывало на всё израильское общество.
* “Собранием” иногда называлось большое количество воинов противника. В таком случае это слово можно перевести как “армия”.
* В Новом Завете в Иерусалиме созывалось собрание из семидесяти старейшин, на котором обсуждались юридические вопросы и разрешались споры между людьми. Такое собрание называлось “синедрионом” или “Советом”.

## Варианты перевода

* В зависимости от контекста, слово “собрание” может переводиться как “паства”, “братство”, “совет”, “армия”, “большая группа людей”.
* Когда это слово относится ко всему израильскому народу, его можно заменить словами “общество” или “народ Израиля”.
* Выражение “всё собрание” можно перевести как “все”, “каждый”, “весь народ”, “все израильтяне”.  (См. [гипербола](rc://*/ta/man/translate/figs-hyperbole))

(См. также: [совет](../other/council.md))

## Ссылки на библейский текст:

* [3 Цар. 8:14-16](rc://*/tn/help/1ki/08/14)
* [Деян. 7:38-40](rc://*/tn/help/act/07/38)
* [Ezra 10:12-13](rc://*/tn/help/ezr/10/12)
* [Евр. 12:22-24](rc://*/tn/help/heb/12/22)
* [Лев. 4:20-21](rc://*/tn/help/lev/04/20)
* [Неем. 8:1-3](rc://*/tn/help/neh/08/01)

## Данные о слове:

* Номера Стронга: H622, H627, H1413, H1481, H2199, H3259, H4150, H4186, H4744, H5475, H5712, H5789, H6116, H6633, H6908, H6950, H6951, H6952, H7284, G1577, G1997, G3831, G4863, G4864, G4871, G4905

==> v9.2.zip: ru_twords_ru_tw/bible/other/assembly.md <==
# собрание, собор

## Определение:

Собрание — это группа людей, собранных с целью обсуждения какой-либо проблемы или для принятия решения. 

* Собранием может быть группа, организованная официально и на постоянной основе, или же это может быть группа, собирающаяся время от времени по особому случаю или для определённой цели. 
* В Ветхом Завете существовало специальное собрание, называемое “торжественным собранием”, когда израильский народ собирался для того, чтобы прославить Божье имя.  
* Иногда это слово указывало на всё израильское общество. 
* “Собранием” иногда называлось большое количество воинов противника. В таком случае это слово можно перевести как “армия”.  
* В Новом Завете в Иерусалиме созывалось собрание из семидесяти старейшин, на котором обсуждались юридические вопросы и разрешались споры между людьми. Такое собрание называлось “синедрионом” или “Советом”.   

## Варианты перевода

* В зависимости от контекста, слово “собрание” может переводиться как “паства”, “братство”, “совет”, “армия”, “большая группа людей”. 
* Когда это слово относится ко всему израильскому народу, его можно заменить словами “общество” или “народ Израиля”. 
* Выражение “всё собрание” можно перевести как “все”, “каждый”, “весь народ”, “все израильтяне”.  (См. [гипербола](rc://ru/ta/man/translate/figs-hyperbole))

(См. также: [совет](../other/council.md))

## Ссылки на библейский текст:

* [3 Цар. 8:14-16](rc://ru/tn/help/1ki/08/14)
* [Деян. 7:38-40](rc://ru/tn/help/act/07/38)
* [Ezra 10:12-13](rc://ru/tn/help/ezr/10/12)
* [Евр. 12:22-24](rc://ru/tn/help/heb/12/22)
* [Лев. 4:20-21](rc://ru/tn/help/lev/04/20)
* [Неем. 8:1-3](rc://ru/tn/help/neh/08/01)

## Данные о слове:

* Номера Стронга: H622, H627, H1413, H1481, H2199, H3259, H4150, H4186, H4744, H5475, H5712, H5789, H6116, H6633, H6908, H6950, H6951, H6952, H7284, G1577, G1997, G3831, G4863, G4864, G4871, G4905
